void __stdcall ActivateKeyboardLayout(int p0, int p1) {}
void __stdcall AddClipboardFormatListener(int p0) {}
void __stdcall AdjustWindowRect(int p0, int p1, int p2) {}
void __stdcall AdjustWindowRectEx(int p0, int p1, int p2, int p3) {}
void __stdcall AdjustWindowRectExForDpi(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall AllowSetForegroundWindow(int p0) {}
void __stdcall AnimateWindow(int p0, int p1, int p2) {}
void __stdcall AnyPopup() {}
void __stdcall AppendMenuA(int p0, int p1, int p2, int p3) {}
void __stdcall AppendMenuW(int p0, int p1, int p2, int p3) {}
void __stdcall AreDpiAwarenessContextsEqual(int p0, int p1) {}
void __stdcall ArrangeIconicWindows(int p0) {}
void __stdcall AttachThreadInput(int p0, int p1, int p2) {}
void __stdcall BeginDeferWindowPos(int p0) {}
void __stdcall BeginPaint(int p0, int p1) {}
void __stdcall BlockInput(int p0) {}
void __stdcall BringWindowToTop(int p0) {}
void __stdcall BroadcastSystemMessageA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall BroadcastSystemMessageExA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall BroadcastSystemMessageExW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall BroadcastSystemMessageW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CalculatePopupWindowPosition(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CallMsgFilterA(int p0, int p1) {}
void __stdcall CallMsgFilterW(int p0, int p1) {}
void __stdcall CallNextHookEx(int p0, int p1, int p2, int p3) {}
void __stdcall CallWindowProcA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CallWindowProcW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CancelShutdown() {}
void __stdcall CascadeWindows(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ChangeClipboardChain(int p0, int p1) {}
void __stdcall ChangeDisplaySettingsA(int p0, int p1) {}
void __stdcall ChangeDisplaySettingsExA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ChangeDisplaySettingsExW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ChangeDisplaySettingsW(int p0, int p1) {}
void __stdcall ChangeMenuA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ChangeMenuW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ChangeWindowMessageFilter(int p0, int p1) {}
void __stdcall ChangeWindowMessageFilterEx(int p0, int p1, int p2, int p3) {}
void __stdcall CharLowerA(int p0) {}
void __stdcall CharLowerBuffA(int p0, int p1) {}
void __stdcall CharLowerBuffW(int p0, int p1) {}
void __stdcall CharLowerW(int p0) {}
void __stdcall CharNextA(int p0) {}
void __stdcall CharNextExA(int p0, int p1, int p2) {}
void __stdcall CharNextW(int p0) {}
void __stdcall CharPrevA(int p0, int p1) {}
void __stdcall CharPrevExA(int p0, int p1, int p2, int p3) {}
void __stdcall CharPrevW(int p0, int p1) {}
void __stdcall CharToOemA(int p0, int p1) {}
void __stdcall CharToOemBuffA(int p0, int p1, int p2) {}
void __stdcall CharToOemBuffW(int p0, int p1, int p2) {}
void __stdcall CharToOemW(int p0, int p1) {}
void __stdcall CharUpperA(int p0) {}
void __stdcall CharUpperBuffA(int p0, int p1) {}
void __stdcall CharUpperBuffW(int p0, int p1) {}
void __stdcall CharUpperW(int p0) {}
void __stdcall CheckDlgButton(int p0, int p1, int p2) {}
void __stdcall CheckMenuItem(int p0, int p1, int p2) {}
void __stdcall CheckMenuRadioItem(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CheckRadioButton(int p0, int p1, int p2, int p3) {}
void __stdcall ChildWindowFromPoint(int p0, int p1, int p2) {}
void __stdcall ChildWindowFromPointEx(int p0, int p1, int p2, int p3) {}
void __stdcall ClientToScreen(int p0, int p1) {}
void __stdcall ClipCursor(int p0) {}
void __stdcall CloseClipboard() {}
void __stdcall CloseDesktop(int p0) {}
void __stdcall CloseGestureInfoHandle(int p0) {}
void __stdcall CloseTouchInputHandle(int p0) {}
void __stdcall CloseWindow(int p0) {}
void __stdcall CloseWindowStation(int p0) {}
void __stdcall ConsoleControl(int p0, int p1, int p2) {}
void __stdcall CopyAcceleratorTableA(int p0, int p1, int p2) {}
void __stdcall CopyAcceleratorTableW(int p0, int p1, int p2) {}
void __stdcall CopyIcon(int p0) {}
void __stdcall CopyImage(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CopyRect(int p0, int p1) {}
void __stdcall CountClipboardFormats() {}
void __stdcall CreateAcceleratorTableA(int p0, int p1) {}
void __stdcall CreateAcceleratorTableW(int p0, int p1) {}
void __stdcall CreateCaret(int p0, int p1, int p2, int p3) {}
void __stdcall CreateCursor(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CreateDesktopA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CreateDesktopExA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall CreateDesktopExW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall CreateDesktopW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CreateDialogIndirectParamA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CreateDialogIndirectParamW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CreateDialogParamA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CreateDialogParamW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CreateIcon(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CreateIconFromResource(int p0, int p1, int p2, int p3) {}
void __stdcall CreateIconFromResourceEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CreateIconIndirect(int p0) {}
void __stdcall CreateMDIWindowA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall CreateMDIWindowW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall CreateMenu() {}
void __stdcall CreatePopupMenu() {}
void __stdcall CreateSyntheticPointerDevice(int p0, int p1, int p2) {}
void __stdcall CreateWindowExA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9, int p10, int p11) {}
void __stdcall CreateWindowExW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9, int p10, int p11) {}
void __stdcall CreateWindowStationA(int p0, int p1, int p2, int p3) {}
void __stdcall CreateWindowStationW(int p0, int p1, int p2, int p3) {}
void __stdcall DdeAbandonTransaction(int p0, int p1, int p2) {}
void __stdcall DdeAccessData(int p0, int p1) {}
void __stdcall DdeAddData(int p0, int p1, int p2, int p3) {}
void __stdcall DdeClientTransaction(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall DdeCmpStringHandles(int p0, int p1) {}
void __stdcall DdeConnect(int p0, int p1, int p2, int p3) {}
void __stdcall DdeConnectList(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DdeCreateDataHandle(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall DdeCreateStringHandleA(int p0, int p1, int p2) {}
void __stdcall DdeCreateStringHandleW(int p0, int p1, int p2) {}
void __stdcall DdeDisconnect(int p0) {}
void __stdcall DdeDisconnectList(int p0) {}
void __stdcall DdeEnableCallback(int p0, int p1, int p2) {}
void __stdcall DdeFreeDataHandle(int p0) {}
void __stdcall DdeFreeStringHandle(int p0, int p1) {}
void __stdcall DdeGetData(int p0, int p1, int p2, int p3) {}
void __stdcall DdeGetLastError(int p0) {}
void __stdcall DdeImpersonateClient(int p0) {}
void __stdcall DdeInitializeA(int p0, int p1, int p2, int p3) {}
void __stdcall DdeInitializeW(int p0, int p1, int p2, int p3) {}
void __stdcall DdeKeepStringHandle(int p0, int p1) {}
void __stdcall DdeNameService(int p0, int p1, int p2, int p3) {}
void __stdcall DdePostAdvise(int p0, int p1, int p2) {}
void __stdcall DdeQueryConvInfo(int p0, int p1, int p2) {}
void __stdcall DdeQueryNextServer(int p0, int p1) {}
void __stdcall DdeQueryStringA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DdeQueryStringW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DdeReconnect(int p0) {}
void __stdcall DdeSetQualityOfService(int p0, int p1, int p2) {}
void __stdcall DdeSetUserHandle(int p0, int p1, int p2) {}
void __stdcall DdeUnaccessData(int p0) {}
void __stdcall DdeUninitialize(int p0) {}
void __stdcall DefDlgProcA(int p0, int p1, int p2, int p3) {}
void __stdcall DefDlgProcW(int p0, int p1, int p2, int p3) {}
void __stdcall DefFrameProcA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DefFrameProcW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DefMDIChildProcA(int p0, int p1, int p2, int p3) {}
void __stdcall DefMDIChildProcW(int p0, int p1, int p2, int p3) {}
void __stdcall DefRawInputProc(int p0, int p1, int p2) {}
void __stdcall DefWindowProcA(int p0, int p1, int p2, int p3) {}
void __stdcall DefWindowProcW(int p0, int p1, int p2, int p3) {}
void __stdcall DeferWindowPos(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall DeleteMenu(int p0, int p1, int p2) {}
void __stdcall DeregisterShellHookWindow(int p0) {}
void __stdcall DestroyAcceleratorTable(int p0) {}
void __stdcall DestroyCaret() {}
void __stdcall DestroyCursor(int p0) {}
void __stdcall DestroyIcon(int p0) {}
void __stdcall DestroyMenu(int p0) {}
void __stdcall DestroySyntheticPointerDevice(int p0) {}
void __stdcall DestroyWindow(int p0) {}
void __stdcall DialogBoxIndirectParamA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DialogBoxIndirectParamW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DialogBoxParamA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DialogBoxParamW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DisableProcessWindowsGhosting() {}
void __stdcall DispatchMessageA(int p0) {}
void __stdcall DispatchMessageW(int p0) {}
void __stdcall DisplayConfigGetDeviceInfo(int p0) {}
void __stdcall DisplayConfigSetDeviceInfo(int p0) {}
void __stdcall DlgDirListA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DlgDirListComboBoxA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DlgDirListComboBoxW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DlgDirListW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DlgDirSelectComboBoxExA(int p0, int p1, int p2, int p3) {}
void __stdcall DlgDirSelectComboBoxExW(int p0, int p1, int p2, int p3) {}
void __stdcall DlgDirSelectExA(int p0, int p1, int p2, int p3) {}
void __stdcall DlgDirSelectExW(int p0, int p1, int p2, int p3) {}
void __stdcall DragDetect(int p0, int p1, int p2) {}
void __stdcall DragObject(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DrawAnimatedRects(int p0, int p1, int p2, int p3) {}
void __stdcall DrawCaption(int p0, int p1, int p2, int p3) {}
void __stdcall DrawEdge(int p0, int p1, int p2, int p3) {}
void __stdcall DrawFocusRect(int p0, int p1) {}
void __stdcall DrawFrameControl(int p0, int p1, int p2, int p3) {}
void __stdcall DrawIcon(int p0, int p1, int p2, int p3) {}
void __stdcall DrawIconEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8) {}
void __stdcall DrawMenuBar(int p0) {}
void __stdcall DrawStateA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall DrawStateW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall DrawTextA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall DrawTextExA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall DrawTextExW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall DrawTextW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall EmptyClipboard() {}
void __stdcall EnableMenuItem(int p0, int p1, int p2) {}
void __stdcall EnableMouseInPointer(int p0) {}
void __stdcall EnableNonClientDpiScaling(int p0) {}
void __stdcall EnableScrollBar(int p0, int p1, int p2) {}
void __stdcall EnableWindow(int p0, int p1) {}
void __stdcall EndDeferWindowPos(int p0) {}
void __stdcall EndDialog(int p0, int p1) {}
void __stdcall EndMenu() {}
void __stdcall EndPaint(int p0, int p1) {}
void __stdcall EnumChildWindows(int p0, int p1, int p2) {}
void __stdcall EnumClipboardFormats(int p0) {}
void __stdcall EnumDesktopWindows(int p0, int p1, int p2) {}
void __stdcall EnumDesktopsA(int p0, int p1, int p2) {}
void __stdcall EnumDesktopsW(int p0, int p1, int p2) {}
void __stdcall EnumDisplayDevicesA(int p0, int p1, int p2, int p3) {}
void __stdcall EnumDisplayDevicesW(int p0, int p1, int p2, int p3) {}
void __stdcall EnumDisplayMonitors(int p0, int p1, int p2, int p3) {}
void __stdcall EnumDisplaySettingsA(int p0, int p1, int p2) {}
void __stdcall EnumDisplaySettingsExA(int p0, int p1, int p2, int p3) {}
void __stdcall EnumDisplaySettingsExW(int p0, int p1, int p2, int p3) {}
void __stdcall EnumDisplaySettingsW(int p0, int p1, int p2) {}
void __stdcall EnumPropsA(int p0, int p1) {}
void __stdcall EnumPropsExA(int p0, int p1, int p2) {}
void __stdcall EnumPropsExW(int p0, int p1, int p2) {}
void __stdcall EnumPropsW(int p0, int p1) {}
void __stdcall EnumThreadWindows(int p0, int p1, int p2) {}
void __stdcall EnumWindowStationsA(int p0, int p1) {}
void __stdcall EnumWindowStationsW(int p0, int p1) {}
void __stdcall EnumWindows(int p0, int p1) {}
void __stdcall EqualRect(int p0, int p1) {}
void __stdcall EvaluateProximityToPolygon(int p0, int p1, int p2, int p3) {}
void __stdcall EvaluateProximityToRect(int p0, int p1, int p2) {}
void __stdcall ExcludeUpdateRgn(int p0, int p1) {}
void __stdcall ExitWindowsEx(int p0, int p1) {}
void __stdcall FillRect(int p0, int p1, int p2) {}
void __stdcall FindWindowA(int p0, int p1) {}
void __stdcall FindWindowExA(int p0, int p1, int p2, int p3) {}
void __stdcall FindWindowExW(int p0, int p1, int p2, int p3) {}
void __stdcall FindWindowW(int p0, int p1) {}
void __stdcall FlashWindow(int p0, int p1) {}
void __stdcall FlashWindowEx(int p0) {}
void __stdcall FrameRect(int p0, int p1, int p2) {}
void __stdcall FreeDDElParam(int p0, int p1) {}
void __stdcall GetActiveWindow() {}
void __stdcall GetAltTabInfoA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetAltTabInfoW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetAncestor(int p0, int p1) {}
void __stdcall GetAsyncKeyState(int p0) {}
void __stdcall GetAutoRotationState(int p0) {}
void __stdcall GetAwarenessFromDpiAwarenessContext(int p0) {}
void __stdcall GetCIMSSM(int p0) {}
void __stdcall GetCapture() {}
void __stdcall GetCaretBlinkTime() {}
void __stdcall GetCaretPos(int p0) {}
void __stdcall GetClassInfoA(int p0, int p1, int p2) {}
void __stdcall GetClassInfoExA(int p0, int p1, int p2) {}
void __stdcall GetClassInfoExW(int p0, int p1, int p2) {}
void __stdcall GetClassInfoW(int p0, int p1, int p2) {}
void __stdcall GetClassLongA(int p0, int p1) {}
void __stdcall GetClassLongPtrA(int p0, int p1) {}
void __stdcall GetClassLongPtrW(int p0, int p1) {}
void __stdcall GetClassLongW(int p0, int p1) {}
void __stdcall GetClassNameA(int p0, int p1, int p2) {}
void __stdcall GetClassNameW(int p0, int p1, int p2) {}
void __stdcall GetClassWord(int p0, int p1) {}
void __stdcall GetClientRect(int p0, int p1) {}
void __stdcall GetClipCursor(int p0) {}
void __stdcall GetClipboardData(int p0) {}
void __stdcall GetClipboardFormatNameA(int p0, int p1, int p2) {}
void __stdcall GetClipboardFormatNameW(int p0, int p1, int p2) {}
void __stdcall GetClipboardOwner() {}
void __stdcall GetClipboardSequenceNumber() {}
void __stdcall GetClipboardViewer() {}
void __stdcall GetComboBoxInfo(int p0, int p1) {}
void __stdcall GetCurrentInputMessageSource(int p0) {}
void __stdcall GetCursor() {}
void __stdcall GetCursorInfo(int p0) {}
void __stdcall GetCursorPos(int p0) {}
void __stdcall GetDC(int p0) {}
void __stdcall GetDCEx(int p0, int p1, int p2) {}
void __stdcall GetDesktopWindow() {}
void __stdcall GetDialogBaseUnits() {}
void __stdcall GetDialogControlDpiChangeBehavior(int p0) {}
void __stdcall GetDialogDpiChangeBehavior(int p0) {}
void __stdcall GetDisplayAutoRotationPreferences(int p0) {}
void __stdcall GetDisplayConfigBufferSizes(int p0, int p1, int p2) {}
void __stdcall GetDlgCtrlID(int p0) {}
void __stdcall GetDlgItem(int p0, int p1) {}
void __stdcall GetDlgItemInt(int p0, int p1, int p2, int p3) {}
void __stdcall GetDlgItemTextA(int p0, int p1, int p2, int p3) {}
void __stdcall GetDlgItemTextW(int p0, int p1, int p2, int p3) {}
void __stdcall GetDoubleClickTime() {}
void __stdcall GetDpiAwarenessContextForProcess(int p0) {}
void __stdcall GetDpiForSystem() {}
void __stdcall GetDpiForWindow(int p0) {}
void __stdcall GetDpiFromDpiAwarenessContext(int p0) {}
void __stdcall GetFocus() {}
void __stdcall GetForegroundWindow() {}
void __stdcall GetGUIThreadInfo(int p0, int p1) {}
void __stdcall GetGestureConfig(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetGestureExtraArgs(int p0, int p1, int p2) {}
void __stdcall GetGestureInfo(int p0, int p1) {}
void __stdcall GetGuiResources(int p0, int p1) {}
void __stdcall GetIconInfo(int p0, int p1) {}
void __stdcall GetIconInfoExA(int p0, int p1) {}
void __stdcall GetIconInfoExW(int p0, int p1) {}
void __stdcall GetInputState() {}
void __stdcall GetKBCodePage() {}
void __stdcall GetKeyNameTextA(int p0, int p1, int p2) {}
void __stdcall GetKeyNameTextW(int p0, int p1, int p2) {}
void __stdcall GetKeyState(int p0) {}
void __stdcall GetKeyboardLayout(int p0) {}
void __stdcall GetKeyboardLayoutList(int p0, int p1) {}
void __stdcall GetKeyboardLayoutNameA(int p0) {}
void __stdcall GetKeyboardLayoutNameW(int p0) {}
void __stdcall GetKeyboardState(int p0) {}
void __stdcall GetKeyboardType(int p0) {}
void __stdcall GetLastActivePopup(int p0) {}
void __stdcall GetLastInputInfo(int p0) {}
void __stdcall GetLayeredWindowAttributes(int p0, int p1, int p2, int p3) {}
void __stdcall GetListBoxInfo(int p0) {}
void __stdcall GetMenu(int p0) {}
void __stdcall GetMenuBarInfo(int p0, int p1, int p2, int p3) {}
void __stdcall GetMenuCheckMarkDimensions() {}
void __stdcall GetMenuContextHelpId(int p0) {}
void __stdcall GetMenuDefaultItem(int p0, int p1, int p2) {}
void __stdcall GetMenuInfo(int p0, int p1) {}
void __stdcall GetMenuItemCount(int p0) {}
void __stdcall GetMenuItemID(int p0, int p1) {}
void __stdcall GetMenuItemInfoA(int p0, int p1, int p2, int p3) {}
void __stdcall GetMenuItemInfoW(int p0, int p1, int p2, int p3) {}
void __stdcall GetMenuItemRect(int p0, int p1, int p2, int p3) {}
void __stdcall GetMenuState(int p0, int p1, int p2) {}
void __stdcall GetMenuStringA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetMenuStringW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetMessageA(int p0, int p1, int p2, int p3) {}
void __stdcall GetMessageExtraInfo() {}
void __stdcall GetMessagePos() {}
void __stdcall GetMessageTime() {}
void __stdcall GetMessageW(int p0, int p1, int p2, int p3) {}
void __stdcall GetMonitorInfoA(int p0, int p1) {}
void __stdcall GetMonitorInfoW(int p0, int p1) {}
void __stdcall GetMouseMovePointsEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetNextDlgGroupItem(int p0, int p1, int p2) {}
void __stdcall GetNextDlgTabItem(int p0, int p1, int p2) {}
void __stdcall GetOpenClipboardWindow() {}
void __stdcall GetParent(int p0) {}
void __stdcall GetPhysicalCursorPos(int p0) {}
void __stdcall GetPointerCursorId(int p0, int p1) {}
void __stdcall GetPointerDevice(int p0, int p1) {}
void __stdcall GetPointerDeviceCursors(int p0, int p1, int p2) {}
void __stdcall GetPointerDeviceProperties(int p0, int p1, int p2) {}
void __stdcall GetPointerDeviceRects(int p0, int p1, int p2) {}
void __stdcall GetPointerDevices(int p0, int p1) {}
void __stdcall GetPointerFrameInfo(int p0, int p1, int p2) {}
void __stdcall GetPointerFrameInfoHistory(int p0, int p1, int p2, int p3) {}
void __stdcall GetPointerFramePenInfo(int p0, int p1, int p2) {}
void __stdcall GetPointerFramePenInfoHistory(int p0, int p1, int p2, int p3) {}
void __stdcall GetPointerFrameTouchInfo(int p0, int p1, int p2) {}
void __stdcall GetPointerFrameTouchInfoHistory(int p0, int p1, int p2, int p3) {}
void __stdcall GetPointerInfo(int p0, int p1) {}
void __stdcall GetPointerInfoHistory(int p0, int p1, int p2) {}
void __stdcall GetPointerInputTransform(int p0, int p1, int p2) {}
void __stdcall GetPointerPenInfo(int p0, int p1) {}
void __stdcall GetPointerPenInfoHistory(int p0, int p1, int p2) {}
void __stdcall GetPointerTouchInfo(int p0, int p1) {}
void __stdcall GetPointerTouchInfoHistory(int p0, int p1, int p2) {}
void __stdcall GetPointerType(int p0, int p1) {}
void __stdcall GetPriorityClipboardFormat(int p0, int p1) {}
void __stdcall GetProcessDefaultLayout(int p0) {}
void __stdcall GetProcessWindowStation() {}
void __stdcall GetPropA(int p0, int p1) {}
void __stdcall GetPropW(int p0, int p1) {}
void __stdcall GetQueueStatus(int p0) {}
void __stdcall GetRawInputBuffer(int p0, int p1, int p2) {}
void __stdcall GetRawInputData(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetRawInputDeviceInfoA(int p0, int p1, int p2, int p3) {}
void __stdcall GetRawInputDeviceInfoW(int p0, int p1, int p2, int p3) {}
void __stdcall GetRawInputDeviceList(int p0, int p1, int p2) {}
void __stdcall GetRawPointerDeviceData(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetRegisteredRawInputDevices(int p0, int p1, int p2) {}
void __stdcall GetScrollBarInfo(int p0, int p1, int p2) {}
void __stdcall GetScrollInfo(int p0, int p1, int p2) {}
void __stdcall GetScrollPos(int p0, int p1) {}
void __stdcall GetScrollRange(int p0, int p1, int p2, int p3) {}
void __stdcall GetShellWindow() {}
void __stdcall GetSubMenu(int p0, int p1) {}
void __stdcall GetSysColor(int p0) {}
void __stdcall GetSysColorBrush(int p0) {}
void __stdcall GetSystemDpiForProcess(int p0) {}
void __stdcall GetSystemMenu(int p0, int p1) {}
void __stdcall GetSystemMetrics(int p0) {}
void __stdcall GetSystemMetricsForDpi(int p0, int p1) {}
void __stdcall GetTabbedTextExtentA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetTabbedTextExtentW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetThreadDesktop(int p0) {}
void __stdcall GetThreadDpiAwarenessContext() {}
void __stdcall GetThreadDpiHostingBehavior() {}
void __stdcall GetTitleBarInfo(int p0, int p1) {}
void __stdcall GetTopWindow(int p0) {}
void __stdcall GetTouchInputInfo(int p0, int p1, int p2, int p3) {}
void __stdcall GetUnpredictedMessagePos() {}
void __stdcall GetUpdateRect(int p0, int p1, int p2) {}
void __stdcall GetUpdateRgn(int p0, int p1, int p2) {}
void __stdcall GetUpdatedClipboardFormats(int p0, int p1, int p2) {}
void __stdcall GetUserObjectInformationA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetUserObjectInformationW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetUserObjectSecurity(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetWindow(int p0, int p1) {}
void __stdcall GetWindowContextHelpId(int p0) {}
void __stdcall GetWindowDC(int p0) {}
void __stdcall GetWindowDisplayAffinity(int p0, int p1) {}
void __stdcall GetWindowDpiAwarenessContext(int p0) {}
void __stdcall GetWindowDpiHostingBehavior(int p0) {}
void __stdcall GetWindowFeedbackSetting(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetWindowInfo(int p0, int p1) {}
void __stdcall GetWindowLongA(int p0, int p1) {}
void __stdcall GetWindowLongPtrA(int p0, int p1) {}
void __stdcall GetWindowLongPtrW(int p0, int p1) {}
void __stdcall GetWindowLongW(int p0, int p1) {}
void __stdcall GetWindowModuleFileNameA(int p0, int p1, int p2) {}
void __stdcall GetWindowModuleFileNameW(int p0, int p1, int p2) {}
void __stdcall GetWindowPlacement(int p0, int p1) {}
void __stdcall GetWindowRect(int p0, int p1) {}
void __stdcall GetWindowRgn(int p0, int p1) {}
void __stdcall GetWindowRgnBox(int p0, int p1) {}
void __stdcall GetWindowTextA(int p0, int p1, int p2) {}
void __stdcall GetWindowTextLengthA(int p0) {}
void __stdcall GetWindowTextLengthW(int p0) {}
void __stdcall GetWindowTextW(int p0, int p1, int p2) {}
void __stdcall GetWindowThreadProcessId(int p0, int p1) {}
void __stdcall GetWindowWord(int p0, int p1) {}
void __stdcall GrayStringA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8) {}
void __stdcall GrayStringW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8) {}
void __stdcall HideCaret(int p0) {}
void __stdcall HiliteMenuItem(int p0, int p1, int p2, int p3) {}
void __stdcall IMPGetIMEA(int p0, int p1) {}
void __stdcall IMPGetIMEW(int p0, int p1) {}
void __stdcall IMPQueryIMEA(int p0) {}
void __stdcall IMPQueryIMEW(int p0) {}
void __stdcall IMPSetIMEA(int p0, int p1) {}
void __stdcall IMPSetIMEW(int p0, int p1) {}
void __stdcall ImpersonateDdeClientWindow(int p0, int p1) {}
void __stdcall InSendMessage() {}
void __stdcall InSendMessageEx(int p0) {}
void __stdcall InflateRect(int p0, int p1, int p2) {}
void __stdcall InheritWindowMonitor(int p0, int p1) {}
void __stdcall InitializeTouchInjection(int p0, int p1) {}
void __stdcall InjectSyntheticPointerInput(int p0, int p1, int p2) {}
void __stdcall InjectTouchInput(int p0, int p1) {}
void __stdcall InsertMenuA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall InsertMenuItemA(int p0, int p1, int p2, int p3) {}
void __stdcall InsertMenuItemW(int p0, int p1, int p2, int p3) {}
void __stdcall InsertMenuW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall InternalGetWindowText(int p0, int p1, int p2) {}
void __stdcall IntersectRect(int p0, int p1, int p2) {}
void __stdcall InvalidateRect(int p0, int p1, int p2) {}
void __stdcall InvalidateRgn(int p0, int p1, int p2) {}
void __stdcall InvertRect(int p0, int p1) {}
void __stdcall IsCharAlphaA(int p0) {}
void __stdcall IsCharAlphaNumericA(int p0) {}
void __stdcall IsCharAlphaNumericW(int p0) {}
void __stdcall IsCharAlphaW(int p0) {}
void __stdcall IsCharLowerA(int p0) {}
void __stdcall IsCharLowerW(int p0) {}
void __stdcall IsCharUpperA(int p0) {}
void __stdcall IsCharUpperW(int p0) {}
void __stdcall IsChild(int p0, int p1) {}
void __stdcall IsClipboardFormatAvailable(int p0) {}
void __stdcall IsDialogMessageA(int p0, int p1) {}
void __stdcall IsDialogMessageW(int p0, int p1) {}
void __stdcall IsDlgButtonChecked(int p0, int p1) {}
void __stdcall IsGUIThread(int p0) {}
void __stdcall IsHungAppWindow(int p0) {}
void __stdcall IsIconic(int p0) {}
void __stdcall IsImmersiveProcess(int p0) {}
void __stdcall IsMenu(int p0) {}
void __stdcall IsMouseInPointerEnabled() {}
void __stdcall IsProcessDPIAware() {}
void __stdcall IsRectEmpty(int p0) {}
void __stdcall IsTouchWindow(int p0, int p1) {}
void __stdcall IsValidDpiAwarenessContext(int p0) {}
void __stdcall IsWinEventHookInstalled(int p0) {}
void __stdcall IsWindow(int p0) {}
void __stdcall IsWindowArranged(int p0) {}
void __stdcall IsWindowEnabled(int p0) {}
void __stdcall IsWindowUnicode(int p0) {}
void __stdcall IsWindowVisible(int p0) {}
void __stdcall IsWow64Message() {}
void __stdcall IsZoomed(int p0) {}
void __stdcall KillTimer(int p0, int p1) {}
void __stdcall LoadAcceleratorsA(int p0, int p1) {}
void __stdcall LoadAcceleratorsW(int p0, int p1) {}
void __stdcall LoadBitmapA(int p0, int p1) {}
void __stdcall LoadBitmapW(int p0, int p1) {}
void __stdcall LoadCursorA(int p0, int p1) {}
void __stdcall LoadCursorFromFileA(int p0) {}
void __stdcall LoadCursorFromFileW(int p0) {}
void __stdcall LoadCursorW(int p0, int p1) {}
void __stdcall LoadIconA(int p0, int p1) {}
void __stdcall LoadIconW(int p0, int p1) {}
void __stdcall LoadImageA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall LoadImageW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall LoadKeyboardLayoutA(int p0, int p1) {}
void __stdcall LoadKeyboardLayoutW(int p0, int p1) {}
void __stdcall LoadMenuA(int p0, int p1) {}
void __stdcall LoadMenuIndirectA(int p0) {}
void __stdcall LoadMenuIndirectW(int p0) {}
void __stdcall LoadMenuW(int p0, int p1) {}
void __stdcall LoadStringA(int p0, int p1, int p2, int p3) {}
void __stdcall LoadStringW(int p0, int p1, int p2, int p3) {}
void __stdcall LockSetForegroundWindow(int p0) {}
void __stdcall LockWindowUpdate(int p0) {}
void __stdcall LockWorkStation() {}
void __stdcall LogicalToPhysicalPoint(int p0, int p1) {}
void __stdcall LogicalToPhysicalPointForPerMonitorDPI(int p0, int p1) {}
void __stdcall LookupIconIdFromDirectory(int p0, int p1) {}
void __stdcall LookupIconIdFromDirectoryEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall MapDialogRect(int p0, int p1) {}
void __stdcall MapVirtualKeyA(int p0, int p1) {}
void __stdcall MapVirtualKeyExA(int p0, int p1, int p2) {}
void __stdcall MapVirtualKeyExW(int p0, int p1, int p2) {}
void __stdcall MapVirtualKeyW(int p0, int p1) {}
void __stdcall MapWindowPoints(int p0, int p1, int p2, int p3) {}
void __stdcall MenuItemFromPoint(int p0, int p1, int p2, int p3) {}
void __stdcall MessageBeep(int p0) {}
void __stdcall MessageBoxA(int p0, int p1, int p2, int p3) {}
void __stdcall MessageBoxExA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall MessageBoxExW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall MessageBoxIndirectA(int p0) {}
void __stdcall MessageBoxIndirectW(int p0) {}
void __stdcall MessageBoxW(int p0, int p1, int p2, int p3) {}
void __stdcall ModifyMenuA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ModifyMenuW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall MonitorFromPoint(int p0, int p1, int p2) {}
void __stdcall MonitorFromRect(int p0, int p1) {}
void __stdcall MonitorFromWindow(int p0, int p1) {}
void __stdcall MoveWindow(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall MsgWaitForMultipleObjects(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall MsgWaitForMultipleObjectsEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall NotifyWinEvent(int p0, int p1, int p2, int p3) {}
void __stdcall OemKeyScan(int p0) {}
void __stdcall OemToCharA(int p0, int p1) {}
void __stdcall OemToCharBuffA(int p0, int p1, int p2) {}
void __stdcall OemToCharBuffW(int p0, int p1, int p2) {}
void __stdcall OemToCharW(int p0, int p1) {}
void __stdcall OffsetRect(int p0, int p1, int p2) {}
void __stdcall OpenClipboard(int p0) {}
void __stdcall OpenDesktopA(int p0, int p1, int p2, int p3) {}
void __stdcall OpenDesktopW(int p0, int p1, int p2, int p3) {}
void __stdcall OpenIcon(int p0) {}
void __stdcall OpenInputDesktop(int p0, int p1, int p2) {}
void __stdcall OpenWindowStationA(int p0, int p1, int p2) {}
void __stdcall OpenWindowStationW(int p0, int p1, int p2) {}
void __stdcall PackDDElParam(int p0, int p1, int p2) {}
void __stdcall PackTouchHitTestingProximityEvaluation(int p0, int p1) {}
void __stdcall PaintDesktop(int p0) {}
void __stdcall PeekMessageA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall PeekMessageW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall PhysicalToLogicalPoint(int p0, int p1) {}
void __stdcall PhysicalToLogicalPointForPerMonitorDPI(int p0, int p1) {}
void __stdcall PostMessageA(int p0, int p1, int p2, int p3) {}
void __stdcall PostMessageW(int p0, int p1, int p2, int p3) {}
void __stdcall PostQuitMessage(int p0) {}
void __stdcall PostThreadMessageA(int p0, int p1, int p2, int p3) {}
void __stdcall PostThreadMessageW(int p0, int p1, int p2, int p3) {}
void __stdcall PrintWindow(int p0, int p1, int p2) {}
void __stdcall PrivateExtractIconsA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall PrivateExtractIconsW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall PtInRect(int p0, int p1, int p2) {}
void __stdcall QueryDisplayConfig(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall RealChildWindowFromPoint(int p0, int p1, int p2) {}
void __stdcall RealGetWindowClassA(int p0, int p1, int p2) {}
void __stdcall RealGetWindowClassW(int p0, int p1, int p2) {}
void __stdcall RedrawWindow(int p0, int p1, int p2, int p3) {}
void __stdcall RegisterClassA(int p0) {}
void __stdcall RegisterClassExA(int p0) {}
void __stdcall RegisterClassExW(int p0) {}
void __stdcall RegisterClassW(int p0) {}
void __stdcall RegisterClipboardFormatA(int p0) {}
void __stdcall RegisterClipboardFormatW(int p0) {}
void __stdcall RegisterDeviceNotificationA(int p0, int p1, int p2) {}
void __stdcall RegisterDeviceNotificationW(int p0, int p1, int p2) {}
void __stdcall RegisterForTooltipDismissNotification(int p0, int p1) {}
void __stdcall RegisterHotKey(int p0, int p1, int p2, int p3) {}
void __stdcall RegisterPointerDeviceNotifications(int p0, int p1) {}
void __stdcall RegisterPointerInputTarget(int p0, int p1) {}
void __stdcall RegisterPointerInputTargetEx(int p0, int p1, int p2) {}
void __stdcall RegisterPowerSettingNotification(int p0, int p1, int p2) {}
void __stdcall RegisterRawInputDevices(int p0, int p1, int p2) {}
void __stdcall RegisterShellHookWindow(int p0) {}
void __stdcall RegisterSuspendResumeNotification(int p0, int p1) {}
void __stdcall RegisterTouchHitTestingWindow(int p0, int p1) {}
void __stdcall RegisterTouchWindow(int p0, int p1) {}
void __stdcall RegisterWindowMessageA(int p0) {}
void __stdcall RegisterWindowMessageW(int p0) {}
void __stdcall ReleaseCapture() {}
void __stdcall ReleaseDC(int p0, int p1) {}
void __stdcall RemoveClipboardFormatListener(int p0) {}
void __stdcall RemoveMenu(int p0, int p1, int p2) {}
void __stdcall RemovePropA(int p0, int p1) {}
void __stdcall RemovePropW(int p0, int p1) {}
void __stdcall ReplyMessage(int p0) {}
void __stdcall ReuseDDElParam(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ScreenToClient(int p0, int p1) {}
void __stdcall ScrollDC(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall ScrollWindow(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ScrollWindowEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall SendDlgItemMessageA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SendDlgItemMessageW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SendIMEMessageExA(int p0, int p1) {}
void __stdcall SendIMEMessageExW(int p0, int p1) {}
void __stdcall SendInput(int p0, int p1, int p2) {}
void __stdcall SendMessageA(int p0, int p1, int p2, int p3) {}
void __stdcall SendMessageCallbackA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall SendMessageCallbackW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall SendMessageTimeoutA(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall SendMessageTimeoutW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall SendMessageW(int p0, int p1, int p2, int p3) {}
void __stdcall SendNotifyMessageA(int p0, int p1, int p2, int p3) {}
void __stdcall SendNotifyMessageW(int p0, int p1, int p2, int p3) {}
void __stdcall SetActiveWindow(int p0) {}
void __stdcall SetAdditionalForegroundBoostProcesses(int p0, int p1, int p2) {}
void __stdcall SetCapture(int p0) {}
void __stdcall SetCaretBlinkTime(int p0) {}
void __stdcall SetCaretPos(int p0, int p1) {}
void __stdcall SetClassLongA(int p0, int p1, int p2) {}
void __stdcall SetClassLongPtrA(int p0, int p1, int p2) {}
void __stdcall SetClassLongPtrW(int p0, int p1, int p2) {}
void __stdcall SetClassLongW(int p0, int p1, int p2) {}
void __stdcall SetClassWord(int p0, int p1, int p2) {}
void __stdcall SetClipboardData(int p0, int p1) {}
void __stdcall SetClipboardViewer(int p0) {}
void __stdcall SetCoalescableTimer(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SetCursor(int p0) {}
void __stdcall SetCursorPos(int p0, int p1) {}
void __stdcall SetDebugErrorLevel(int p0) {}
void __stdcall SetDialogControlDpiChangeBehavior(int p0, int p1, int p2) {}
void __stdcall SetDialogDpiChangeBehavior(int p0, int p1, int p2) {}
void __stdcall SetDisplayAutoRotationPreferences(int p0) {}
void __stdcall SetDisplayConfig(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SetDlgItemInt(int p0, int p1, int p2, int p3) {}
void __stdcall SetDlgItemTextA(int p0, int p1, int p2) {}
void __stdcall SetDlgItemTextW(int p0, int p1, int p2) {}
void __stdcall SetDoubleClickTime(int p0) {}
void __stdcall SetFocus(int p0) {}
void __stdcall SetForegroundWindow(int p0) {}
void __stdcall SetGestureConfig(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SetKeyboardState(int p0) {}
void __stdcall SetLastErrorEx(int p0, int p1) {}
void __stdcall SetLayeredWindowAttributes(int p0, int p1, int p2, int p3) {}
void __stdcall SetMenu(int p0, int p1) {}
void __stdcall SetMenuContextHelpId(int p0, int p1) {}
void __stdcall SetMenuDefaultItem(int p0, int p1, int p2) {}
void __stdcall SetMenuInfo(int p0, int p1) {}
void __stdcall SetMenuItemBitmaps(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SetMenuItemInfoA(int p0, int p1, int p2, int p3) {}
void __stdcall SetMenuItemInfoW(int p0, int p1, int p2, int p3) {}
void __stdcall SetMessageExtraInfo(int p0) {}
void __stdcall SetMessageQueue(int p0) {}
void __stdcall SetParent(int p0, int p1) {}
void __stdcall SetPhysicalCursorPos(int p0, int p1) {}
void __stdcall SetProcessDPIAware() {}
void __stdcall SetProcessDefaultLayout(int p0) {}
void __stdcall SetProcessDpiAwarenessContext(int p0) {}
void __stdcall SetProcessRestrictionExemption(int p0) {}
void __stdcall SetProcessWindowStation(int p0) {}
void __stdcall SetPropA(int p0, int p1, int p2) {}
void __stdcall SetPropW(int p0, int p1, int p2) {}
void __stdcall SetRect(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SetRectEmpty(int p0) {}
void __stdcall SetScrollInfo(int p0, int p1, int p2, int p3) {}
void __stdcall SetScrollPos(int p0, int p1, int p2, int p3) {}
void __stdcall SetScrollRange(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SetSysColors(int p0, int p1, int p2) {}
void __stdcall SetSystemCursor(int p0, int p1) {}
void __stdcall SetThreadDesktop(int p0) {}
void __stdcall SetThreadDpiAwarenessContext(int p0) {}
void __stdcall SetThreadDpiHostingBehavior(int p0) {}
void __stdcall SetTimer(int p0, int p1, int p2, int p3) {}
void __stdcall SetUserObjectInformationA(int p0, int p1, int p2, int p3) {}
void __stdcall SetUserObjectInformationW(int p0, int p1, int p2, int p3) {}
void __stdcall SetUserObjectSecurity(int p0, int p1, int p2) {}
void __stdcall SetWinEventHook(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall SetWindowContextHelpId(int p0, int p1) {}
void __stdcall SetWindowDisplayAffinity(int p0, int p1) {}
void __stdcall SetWindowFeedbackSetting(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SetWindowLongA(int p0, int p1, int p2) {}
void __stdcall SetWindowLongPtrA(int p0, int p1, int p2) {}
void __stdcall SetWindowLongPtrW(int p0, int p1, int p2) {}
void __stdcall SetWindowLongW(int p0, int p1, int p2) {}
void __stdcall SetWindowPlacement(int p0, int p1) {}
void __stdcall SetWindowPos(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall SetWindowRgn(int p0, int p1, int p2) {}
void __stdcall SetWindowTextA(int p0, int p1) {}
void __stdcall SetWindowTextW(int p0, int p1) {}
void __stdcall SetWindowWord(int p0, int p1, int p2) {}
void __stdcall SetWindowsHookA(int p0, int p1) {}
void __stdcall SetWindowsHookExA(int p0, int p1, int p2, int p3) {}
void __stdcall SetWindowsHookExW(int p0, int p1, int p2, int p3) {}
void __stdcall SetWindowsHookW(int p0, int p1) {}
void __stdcall ShowCaret(int p0) {}
void __stdcall ShowCursor(int p0) {}
void __stdcall ShowOwnedPopups(int p0, int p1) {}
void __stdcall ShowScrollBar(int p0, int p1, int p2) {}
void __stdcall ShowWindow(int p0, int p1) {}
void __stdcall ShowWindowAsync(int p0, int p1) {}
void __stdcall ShutdownBlockReasonCreate(int p0, int p1) {}
void __stdcall ShutdownBlockReasonDestroy(int p0) {}
void __stdcall ShutdownBlockReasonQuery(int p0, int p1, int p2) {}
void __stdcall SkipPointerFrameMessages(int p0) {}
void __stdcall SoundSentry() {}
void __stdcall SubtractRect(int p0, int p1, int p2) {}
void __stdcall SwapMouseButton(int p0) {}
void __stdcall SwitchDesktop(int p0) {}
void __stdcall SwitchToThisWindow(int p0, int p1) {}
void __stdcall SystemParametersInfoA(int p0, int p1, int p2, int p3) {}
void __stdcall SystemParametersInfoForDpi(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SystemParametersInfoW(int p0, int p1, int p2, int p3) {}
void __stdcall TabbedTextOutA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall TabbedTextOutW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall TileWindows(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ToAscii(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ToAsciiEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall ToUnicode(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall ToUnicodeEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall TrackMouseEvent(int p0) {}
void __stdcall TrackPopupMenu(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall TrackPopupMenuEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall TranslateAcceleratorA(int p0, int p1, int p2) {}
void __stdcall TranslateAcceleratorW(int p0, int p1, int p2) {}
void __stdcall TranslateMDISysAccel(int p0, int p1) {}
void __stdcall TranslateMessage(int p0) {}
void __stdcall UnhookWinEvent(int p0) {}
void __stdcall UnhookWindowsHook(int p0, int p1) {}
void __stdcall UnhookWindowsHookEx(int p0) {}
void __stdcall UnionRect(int p0, int p1, int p2) {}
void __stdcall UnloadKeyboardLayout(int p0) {}
void __stdcall UnpackDDElParam(int p0, int p1, int p2, int p3) {}
void __stdcall UnregisterClassA(int p0, int p1) {}
void __stdcall UnregisterClassW(int p0, int p1) {}
void __stdcall UnregisterDeviceNotification(int p0) {}
void __stdcall UnregisterHotKey(int p0, int p1) {}
void __stdcall UnregisterPointerInputTarget(int p0, int p1) {}
void __stdcall UnregisterPointerInputTargetEx(int p0, int p1) {}
void __stdcall UnregisterPowerSettingNotification(int p0) {}
void __stdcall UnregisterSuspendResumeNotification(int p0) {}
void __stdcall UnregisterTouchWindow(int p0) {}
void __stdcall UpdateLayeredWindow(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8) {}
void __stdcall UpdateLayeredWindowIndirect(int p0, int p1) {}
void __stdcall UpdateWindow(int p0) {}
void __stdcall UserHandleGrantAccess(int p0, int p1, int p2) {}
void __stdcall ValidateRect(int p0, int p1) {}
void __stdcall ValidateRgn(int p0, int p1) {}
void __stdcall VkKeyScanA(int p0) {}
void __stdcall VkKeyScanExA(int p0, int p1) {}
void __stdcall VkKeyScanExW(int p0, int p1) {}
void __stdcall VkKeyScanW(int p0) {}
void __stdcall WINNLSEnableIME(int p0, int p1) {}
void __stdcall WINNLSGetEnableStatus(int p0) {}
void __stdcall WINNLSGetIMEHotkey(int p0) {}
void __stdcall WaitForInputIdle(int p0, int p1) {}
void __stdcall WaitMessage() {}
void __stdcall WinHelpA(int p0, int p1, int p2, int p3) {}
void __stdcall WinHelpW(int p0, int p1, int p2, int p3) {}
void __stdcall WindowFromDC(int p0) {}
void __stdcall WindowFromPhysicalPoint(int p0, int p1) {}
void __stdcall WindowFromPoint(int p0, int p1) {}
void __stdcall keybd_event(int p0, int p1, int p2, int p3) {}
void __stdcall mouse_event(int p0, int p1, int p2, int p3, int p4) {}
void __cdecl wsprintfA() {}
void __cdecl wsprintfW() {}
void __stdcall wvsprintfA(int p0, int p1, int p2) {}
void __stdcall wvsprintfW(int p0, int p1, int p2) {}
